@@ -34,7 +34,7 @@ def oauth2_oidc(*args, **kwargs) -> Session:
     """
     id_token = kwargs['id_token']
     #  check that the id_token is not expired
-    decoded = jwt.decode(kwargs['id_token'], verify=False, options={'verify_signature': False})
+    decoded = jwt.decode(kwargs['id_token'], options={'verify_signature': False})
     if datetime.fromtimestamp(decoded['exp']) < datetime.now():
         response = requests.post(
             kwargs['token_endpoint'],
@@ -81,7 +81,12 @@ class CustomTokenServer(AuthBase):
         res = session.request(**self.request_kwargs)
         token = pyjq.first(self.filter, res.json())
 
-        r.headers['Authorization'] = f'Bearer {token}'
+        # If a single string is returned by the filter default
+        # on OAuth "Bearer" auth-scheme.
+        if len(f'{token}'.split(maxsplit=2)) == 1:
+            token = f'Bearer {token}'
+
+        r.headers['Authorization'] = token
         return r
 
 
