@@ -1,4 +1,8 @@
+from enum import Enum
+from typing import Optional
+
 import pandas as pd
+from pydantic import Field, SecretStr, constr
 from pyhive import hive
 
 from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
@@ -6,7 +10,16 @@ from toucan_connectors.toucan_connector import ToucanConnector, ToucanDataSource
 
 class HiveDataSource(ToucanDataSource):
     database: str = 'default'
-    query: str
+    query: constr(min_length=1) = Field(..., widget='sql')
+
+
+class AuthType(str, Enum):
+    NONE = 'NONE'
+    BASIC = 'BASIC'
+    NOSASL = 'NOSASL'
+    KERBEROS = 'KERBEROS'
+    LDAP = 'LDAP'
+    CUSTOM = 'CUSTOM'
 
 
 class HiveConnector(ToucanConnector):
@@ -14,11 +27,13 @@ class HiveConnector(ToucanConnector):
 
     host: str
     port: int = 10000
-    auth: str = 'NONE'
-    configuration: dict = None
-    kerberos_service_name: str = None
-    username: str = None
-    password: str = None
+    auth: AuthType = AuthType.NONE
+    configuration: Optional[dict] = Field(None, description='A dictionary of Hive settings')
+    kerberos_service_name: Optional[str] = Field(None, description="Use with auth='KERBEROS' only")
+    username: Optional[str] = None
+    password: Optional[SecretStr] = Field(
+        None, description="Use with auth='LDAP' or auth='CUSTOM' only"
+    )
 
     def _retrieve_data(self, data_source: HiveDataSource) -> pd.DataFrame:
         cursor = hive.connect(
@@ -29,7 +44,7 @@ class HiveConnector(ToucanConnector):
             auth=self.auth,
             configuration=self.configuration,
             kerberos_service_name=self.kerberos_service_name,
-            password=self.password,
+            password=self.password.get_secret_value() if self.password else None,
         ).cursor()
         cursor.execute(data_source.query, parameters=data_source.parameters)
         columns = [metadata[0] for metadata in cursor.description]
