@@ -239,12 +239,24 @@ class SnowflakeConnector(ToucanConnector):
     def _refresh_oauth_token(self):
         """Regenerates an oauth token if configuration was provided and if the given token has expired."""
         if self.token_endpoint and self.refresh_token:
-            access_token = jwt.decode(
-                self.access_token,
-                verify=False,
-                options={'verify_signature': False},
-            )
-            if datetime.fromtimestamp(access_token['exp']) < datetime.now():
+            try:
+                # Here, we only want to access the expiration date, we don't care if the token is not valid
+                access_token = jwt.decode(
+                    self.access_token,
+                    options={
+                        'verify_signature': False,  # this should be enough according to docs, but doesn't seem like it is
+                        'verify_exp': False,
+                        'verify_nbf': False,
+                        'verify_iat': False,
+                        'verify_aud': False,
+                        'verify_iss': False,
+                    },
+                )
+                is_expired = datetime.fromtimestamp(access_token['exp']) < datetime.now()
+            except Exception:
+                is_expired = True
+
+            if is_expired:
                 res = requests.post(
                     self.token_endpoint,
                     data={
